==> maleo_core-0.3.84-py3-none-any.whl: maleo_core/models/maleo_suite/maleo_soapie/transfers/general/__init__.py <==
# This file serves all MaleoSOAPIE's General Transfers

from __future__ import annotations
from .soapie import MaleoSOAPIESOAPIEGeneralTransfers
from .subjective import MaleoSOAPIESubjectiveGeneralTransfers
from .objective import MaleoSOAPIEObjectiveGeneralTransfers
from .vital_sign import MaleoSOAPIEVitalSignGeneralTransfers
from .assessment import MaleoSOAPIEAssessmentGeneralTransfers
from .diagnosis import MaleoSOAPIEDiagnosisGeneralTransfers
from .plan import MaleoSOAPIEPlanGeneralTransfers
from .intervention import MaleoSOAPIEInterventionGeneralTransfers
from .evaluation import MaleoSOAPIEEvaluationGeneralTransfers

class MaleoSOAPIEGeneralTransfers:
    SOAPIE = MaleoSOAPIESOAPIEGeneralTransfers
    Subjective = MaleoSOAPIESubjectiveGeneralTransfers
    Objective = MaleoSOAPIEObjectiveGeneralTransfers
    VitalSign = MaleoSOAPIEVitalSignGeneralTransfers
    Assessment = MaleoSOAPIEAssessmentGeneralTransfers
    Diagnosis = MaleoSOAPIEDiagnosisGeneralTransfers
    Plan = MaleoSOAPIEPlanGeneralTransfers
    Intervention = MaleoSOAPIEInterventionGeneralTransfers
    Evaluation = MaleoSOAPIEEvaluationGeneralTransfers

__all__ = [
    "MaleoSOAPIEGeneralTransfers",
    "MaleoSOAPIESOAPIEGeneralTransfers",
    "MaleoSOAPIESubjectiveGeneralTransfers",
    "MaleoSOAPIEObjectiveGeneralTransfers",
    "MaleoSOAPIEAssessmentGeneralTransfers",
    "MaleoSOAPIEDiagnosisGeneralTransfers",
    "MaleoSOAPIEPlanGeneralTransfers",
    "MaleoSOAPIEInterventionGeneralTransfers",
    "MaleoSOAPIEEvaluationGeneralTransfers"
]

==> maleo_core-0.3.91-py3-none-any.whl: maleo_core/models/maleo_suite/maleo_soapie/transfers/general/__init__.py <==
# This file serves all MaleoSOAPIE's General Transfers

from __future__ import annotations
from .subjective import MaleoSOAPIESubjectiveGeneralTransfers
from .vital_sign import MaleoSOAPIEVitalSignGeneralTransfers
from .objective import MaleoSOAPIEObjectiveGeneralTransfers
from .diagnosis import MaleoSOAPIEDiagnosisGeneralTransfers
from .assessment import MaleoSOAPIEAssessmentGeneralTransfers
from .plan import MaleoSOAPIEPlanGeneralTransfers
from .intervention import MaleoSOAPIEInterventionGeneralTransfers
from .evaluation import MaleoSOAPIEEvaluationGeneralTransfers
from .soapie import MaleoSOAPIESOAPIEGeneralTransfers

class MaleoSOAPIEGeneralTransfers:
    Subjective = MaleoSOAPIESubjectiveGeneralTransfers
    VitalSign = MaleoSOAPIEVitalSignGeneralTransfers
    Objective = MaleoSOAPIEObjectiveGeneralTransfers
    Diagnosis = MaleoSOAPIEDiagnosisGeneralTransfers
    Assessment = MaleoSOAPIEAssessmentGeneralTransfers
    Plan = MaleoSOAPIEPlanGeneralTransfers
    Intervention = MaleoSOAPIEInterventionGeneralTransfers
    Evaluation = MaleoSOAPIEEvaluationGeneralTransfers
    SOAPIE = MaleoSOAPIESOAPIEGeneralTransfers

__all__ = [
    "MaleoSOAPIEGeneralTransfers",
    "MaleoSOAPIESubjectiveGeneralTransfers",
    "MaleoSOAPIEVitalSignGeneralTransfers",
    "MaleoSOAPIEObjectiveGeneralTransfers",
    "MaleoSOAPIEDiagnosisGeneralTransfers",
    "MaleoSOAPIEAssessmentGeneralTransfers",
    "MaleoSOAPIEPlanGeneralTransfers",
    "MaleoSOAPIEInterventionGeneralTransfers",
    "MaleoSOAPIEEvaluationGeneralTransfers",
    "MaleoSOAPIESOAPIEGeneralTransfers"
]
